@@ -3,7 +3,7 @@ get_model_matrix_attribute <- function(model, newdata = NULL) {
     if (!isTRUE(class(model)[1] %in% c("lm", "glm", "rq"))) {
         return(newdata)
     }
-    
+
     # stats::model.matrix creates all-0 columns with splines::bs() and other functions
     # this may be too aggressive, but it avoids all functions
     flag <- any(grepl("\\(", setdiff(names(get_coef(model)), "(Intercept)")))
@@ -17,7 +17,10 @@ get_model_matrix_attribute <- function(model, newdata = NULL) {
     }
 
     # subset variables for listwise deletion
-    vars <- unlist(insight::find_predictors(model), use.names = FALSE)
+    vars <- unlist(
+        insight::find_predictors(model, verbose = FALSE),
+        use.names = FALSE
+    )
     vars <- c(vars, unlist(insight::find_response(model), use.names = FALSE))
     vars <- intersect(vars, colnames(newdata))
 
@@ -26,4 +29,3 @@ get_model_matrix_attribute <- function(model, newdata = NULL) {
     attr(newdata, "marginaleffects_model_matrix") <- MM
     return(newdata)
 }
-
