@@ -1,20 +1,31 @@
 #' @rdname get_predict
 #' @export
-get_predict.fixest <- function(model,
-                               newdata = insight::get_data(model),
-                               type = "response",
-                               ...) {
-
+get_predict.fixest <- function(
+    model,
+    newdata = insight::get_data(model),
+    type = "response",
+    ...
+) {
     insight::check_if_installed("fixest")
 
     if (is.null(type)) {
-        type <- sanitize_type(model = model, type = type, calling_function = "predictions")
+        type <- sanitize_type(
+            model = model,
+            type = type,
+            calling_function = "predictions"
+        )
     }
 
     dots <- list(...)
 
     # some predict methods raise warnings on unused arguments
-    unused <- c("normalize_dydx", "step_size", "numDeriv_method", "conf.int", "internal_call")
+    unused <- c(
+        "normalize_dydx",
+        "step_size",
+        "numDeriv_method",
+        "conf.int",
+        "internal_call"
+    )
     dots <- dots[setdiff(names(dots), unused)]
 
     # fixest is super slow when using do call because of some `deparse()` call
@@ -24,8 +35,10 @@ get_predict.fixest <- function(model,
         stats::predict(
             object = model,
             newdata = newdata,
-            type = type),
-        silent = TRUE)
+            type = type
+        ),
+        silent = TRUE
+    )
 
     if (inherits(pred, "try-error")) {
         return(pred)
@@ -34,11 +47,13 @@ get_predict.fixest <- function(model,
     if ("rowid" %in% colnames(newdata)) {
         out <- data.frame(
             rowid = newdata$rowid,
-            estimate = as.numeric(pred))
+            estimate = as.numeric(pred)
+        )
     } else {
         out <- data.frame(
             rowid = seq_len(nrow(newdata)),
-            estimate = as.numeric(pred))
+            estimate = as.numeric(pred)
+        )
     }
 
     return(out)
