@@ -2,21 +2,21 @@
 #' @rdname set_coef
 #' @export
 set_coef.mlm <- function(model, coefs, ...) {
+    model$coefficients[] <- coefs
 
-  model$coefficients[] <- coefs
-
-  return(model)
+    return(model)
 }
 
 #' @include get_coef.R
 #' @rdname get_coef
 #' @export
 get_coef.mlm <- function(model, ...) {
-  out <- insight::get_parameters(model, ...)
-  out <- stats::setNames(
-    out$Estimate,
-    sprintf("%s:%s", out$Response, out$Parameter))
-  return(out)
+    out <- insight::get_parameters(model, ...)
+    out <- stats::setNames(
+        out$Estimate,
+        sprintf("%s:%s", out$Response, out$Parameter)
+    )
+    return(out)
 }
 
 
@@ -24,8 +24,6 @@ get_coef.mlm <- function(model, ...) {
 #' @rdname get_group_names
 #' @export
 get_group_names.mlm <- function(model, ...) {
-  resp <- insight::get_response(model)
-  return(names(resp))
+    resp <- insight::get_response(model)
+    return(names(resp))
 }
-
-
