@@ -129,6 +129,11 @@ print.marginaleffects <- function(
         }
     }
 
+    # don't print df if they're all infinite
+    if ("df" %in% colnames(out) && all(out$df == Inf, na.rm = TRUE)) {
+        out[["df"]] <- NULL
+    }
+
     # rename
     dict <- c(
         "term" = "Term",
@@ -246,6 +251,7 @@ print.marginaleffects <- function(
     # avoid infinite recursion by stripping marginaleffect.summary class
     data.table::setDF(out)
 
+
     if (style %in% c("tinytable", "html", "latex", "typst", "markdown")) {
         insight::check_if_installed("tinytable")
 
@@ -277,6 +283,7 @@ print.marginaleffects <- function(
         return(invisible(tab))
     }
 
+        
     # head
     cat("\n")
     print_head <- attr(x, "print_head")
